gym-ignition
============

**gym-ignition is a simple framework to create reproducible robotics environments for reinforcement learning research.**

.. toctree::
   :maxdepth: 1
   :caption: Installation:

   installation/intro
   installation/stable
   installation/nightly
   installation/optional_dependencies

.. toctree::
   :maxdepth: 2
   :caption: ScenarI/O C++ API:

   breathe/core
   breathe/gazebo

.. toctree::
   :maxdepth: 4
   :caption: Python Packages

   apidoc/scenario/scenario.bindings
   apidoc/gym-ignition/gym_ignition
   apidoc/gym-ignition-environments/gym_ignition_environments

.. toctree::
   :maxdepth: 2
   :caption: Information

   info/faq
   info/limitations
